@@ -10,7 +10,7 @@ use constant {
     LP    => 0,
 };
 
-our $VERSION = 1.2;
+our $VERSION = 1.0;
 
 1;
 
@@ -61,8 +61,8 @@ sub insert {
     my $ls = $this->{ls};
 
     while( defined( my $ar = shift ) ) {
-        croak "arguments to insert must be four tuple (open,high,low,close) with high greater than or equal to low"
-            unless ref($ar) eq "ARRAY" and @$ar==4 and $ar->[2]<=$ar->[1];
+        croak "arguments to insert must be four touples (open,high,low,close)"
+            unless ref($ar) eq "ARRAY" and @$ar==4 and $ar->[2]<$ar->[1];
 
         # NOTE: we really only use open and close to initialize ...
         ($open,$high,$low,$close) = @$ar;
@@ -159,6 +159,28 @@ sub insert {
     @{$this->{y}} = ($y_low, $y_high);
 }
 
+sub query_internals {
+    my $this = shift;
+
+    return (
+        $this->{S},
+        $this->{A},
+        $this->{e},
+        $this->{y},
+        $this->{ls},
+    );
+}
+
+sub start_with {
+    my $this = shift;
+
+    $this->{S}  = shift;
+    $this->{A}  = shift;
+    $this->{e}  = shift;
+    $this->{y}  = shift;
+    $this->{ls} = shift;
+}
+
 sub query {
     my $this = shift;
 
@@ -219,6 +241,15 @@ Math::Business::ParabolicSAR - Technical Analysis: Stop and Reversal (aka SAR)
   print "The SAR is long  today.\n" if $sar->long;
   print "The SAR is short today.\n" if $sar->short;
 
+  # You may use this to kick start like this
+  $sar->start_with(@internals);
+
+  # This module keeps track of quite a few more internals than
+  # others in this family, and most of them are useless for
+  # anything besides calculating the next SAR...  Query them like
+  # this:
+  my @internals = $sar->query_internals;
+
 =head1 RESEARCHER
 
 The Parabolic Stop and Reversal was designed by J. Welles Wilder Jr circa 1978.
@@ -232,10 +263,6 @@ Wilder himself felt the SAR was particularly vulnerable to "whipsaws" and
 recommended only using the SAR when the ADX is above 30 -- that is, when there
 is a strong trend going.
 
-=head1 THANKS
-
-Gustav <gustavf@gmail.com>
-
 =head1 AUTHOR
 
 Paul Miller <jettero@cpan.org>
@@ -246,9 +273,6 @@ please let me know.
 I normally hang out on #perl on freenode, so you can try to get immediate
 gratification there if you like.  L<irc://irc.freenode.net/perl>
 
-There is also a mailing list with very light traffic that you might want to
-join: L<http://groups.google.com/group/stockmonkey/>.
-
 =head1 COPYRIGHT
 
 Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
